# Benjy

Benjy is a data as code tool allowing users to 

* declaratively define and build your data environment
* Defines the relationships between data throughout the organization in code.
* Data search, discovery, and lineage.

## Getting started

Source code is available on [github](https://github.com/grai-io/benjy) and binary installers via pip.

```
pip install benjy
```

## Quick Start Guide



